OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Dodano med priljubljene",
    "Removed from favorites" : "Odstranjeno iz priljubljenih",
    "You added {file} to your favorites" : "Med priljubljene dodate datoteko {file}",
    "You removed {file} from your favorites" : "Odstranite datoteko {file} od priljubljenih",
    "Favorites" : "Priljubljene",
    "File changes" : "Spremembe datoteke",
    "Created by {user}" : "{user} ustvari predmet",
    "Changed by {user}" : "{user} spremeni predmet",
    "Deleted by {user}" : "{user} izbriše predmet",
    "Restored by {user}" : "{user} obnovi predmet",
    "Renamed by {user}" : "{user} preimenuje predmet",
    "Moved by {user}" : "{user} premakne predmet",
    "\"remote account\"" : "»oddaljeni račun«",
    "You created {file}" : "Ustvarite datoteko ali mapo {file}",
    "You created an encrypted file in {file}" : "Ustvarite šifrirano datoteko v {file}",
    "{user} created {file}" : "{user} ustvari datoteko {file}",
    "{user} created an encrypted file in {file}" : "{user} ustvari šifrirano datoteko v {file}",
    "{file} was created in a public folder" : "Datoteka {file} je ustvarjena v javni mapi",
    "You changed {file}" : "Spremenite {file}",
    "You changed an encrypted file in {file}" : "Spremenite šifrirano datoteko v {file}",
    "{user} changed {file}" : "{user} spremeni datoteko {file}",
    "{user} changed an encrypted file in {file}" : "Uporabnik {user} spremeni šifrirano datoteko {file}",
    "You deleted {file}" : "Izbrišete datoteko {file}",
    "You deleted an encrypted file in {file}" : "Izbrišete šifrirano datoteko {file}",
    "{user} deleted {file}" : "{user} izbriše datoteko {file}",
    "{user} deleted an encrypted file in {file}" : "{user} izbriše šifrirano datoteko {file}",
    "You restored {file}" : "Obnovite datoteko {file}",
    "{user} restored {file}" : "{user} obnovi datoteko {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Preimenujete datoteko {oldfile} (skrito) v {newfile} (skrito)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Preimenujete {oldfile} (skrito) v {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Preimenujete datoteko {oldfile} v {newfile} (skrito)",
    "You renamed {oldfile} to {newfile}" : "Preimenujete datoteko {oldfile} v {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} preimenuje datoteko {oldfile} (skrito) v {newfile} (skrito)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} preimenuje {oldfile} (skrito) v {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} preimenuje datoteko {oldfile} v {newfile} (skrito)",
    "{user} renamed {oldfile} to {newfile}" : "{user} preimenuje datoteko {oldfile} v {newfile}",
    "You moved {oldfile} to {newfile}" : "Premaknete datoteko {oldfile} v {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} premakne datoteko {oldfile} v {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Datoteka je bila, ali dodana ali umaknjena iz <strong>priljubljenih</strong>",
    "Files" : "Datoteke",
    "A file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila datoteka ali mapa",
    "A favorite file or folder has been <strong>changed</strong>" : "<strong>Spremenjena</strong> je bila priljubljena datoteka ali mapa",
    "Failed to authorize" : "Overitev je spodletela",
    "Invalid folder path" : "Neveljavna pot mape",
    "Folder not found" : "Mape ni mogoče najti",
    "The file cannot be found" : "Datoteke ni mogoče najti.",
    "The destination path does not exist: %1$s" : "Cilja pot ne obstaja: %1$s",
    "You do not have permission to create a file at the specified location" : "Nimate pravice za stvarjenje datoteke na podani lokaciji",
    "The file could not be converted." : "Datoteke ni mogoče pretvoriti.",
    "Could not get relative path to converted file" : "Ni mogoče pridobiti relativne poti do pretvorjene datoteke.",
    "Favorite files" : "Priljubljene datoteke",
    "No favorites" : "Ni priljubljenih datotek",
    "More favorites" : "Več priljubljenih",
    "Accept" : "Sprejmi",
    "Reject" : "Zavrni",
    "Incoming ownership transfer from {user}" : "Vpisana je zahteva za prenos lastništva uporabnika {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Ali želite sprejeti pot {path}?\n\nOpomba: po sprejetju lahko prenos traja tudi več kot 1 uro.",
    "Ownership transfer denied" : "Prenos lastništva je spodletel",
    "Your ownership transfer of {path} was denied by {user}." : "Prenos lastništva za {path} je onemogočil {user}.",
    "Ownership transfer failed" : "Prenos lastništva je spodletel",
    "Your ownership transfer of {path} to {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
    "The ownership transfer of {path} from {user} failed." : "Prenos lastništva mesta {path} na uporabnika {user} je spodletel.",
    "Ownership transfer done" : "Prenos lastništva je uspešno končan",
    "Your ownership transfer of {path} to {user} has completed." : "Prenos lastništva poti {path} na uporabnika {user} je končan.",
    "The ownership transfer of {path} from {user} has completed." : "Prenos lastništva poti {path} z uporabnika {user} je končan.",
    "in %s" : "v %s",
    "Transferred from %1$s on %2$s" : "Preneseno iz %1$s na %2$s",
    "File Management" : "Upravljanje datotek",
    "Home" : "Začetni pogled",
    "Target folder does not exist any more" : "Ciljna mapa ne obstaja več",
    "Reload current directory" : "Ponovno naloži trenutno mapo",
    "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
    "Current directory path" : "Trenutna pot mape",
    "Share" : "·Souporaba·",
    "Your have used your space quota and cannot upload files anymore" : "Porabili ste svojo količino prostora in datotek več ne morete nalagati",
    "You do not have permission to upload or create files here." : "Nimate pravic za ustvarjanje ali nalaganje datotek na to mesto.",
    "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
    "Favorite" : "Priljubljene",
    "Back" : "Nazaj",
    "Toggle selection for file \"{displayName}\"" : "Preklopi izbor za datoteko \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Preklopi izbor za mapo \"{displayName}\"",
    "File is loading" : "Poteka nalaganje datoteke",
    "Folder is loading" : "mape",
    "Filename" : "Ime datoteke",
    "Folder name" : "Ime mape",
    "This node is unavailable" : "To vozlišče ni na voljo.",
    "Another entry with the same name already exists." : "Vpis z istim imenom že obstaja.",
    "Invalid filename." : "Neveljavno ime datoteke",
    "Rename file" : "Preimenuj datoteke",
    "Folder" : "Mapa",
    "Pending" : "Na čakanju ...",
    "Unknown date" : "Neznani datum",
    "Active filters" : "Dejavni filtri",
    "Remove filter" : "Odstrani filter",
    "Today" : "Danes",
    "Last 7 days" : "Zadnjih 7 dni",
    "Last 30 days" : "Zadnjih 30 dni",
    "This year ({year})" : "Letos ({year})",
    "Last year ({year})" : "Lansko leto ({year})",
    "Custom date range" : "Obseg datuma po meri",
    "Search everywhere" : "Išči povsod",
    "Documents" : "Dokumenti",
    "Spreadsheets" : "Preglednice",
    "Presentations" : "Predstavitve",
    "PDFs" : "Dokumenti PDF",
    "Folders" : "Mape",
    "Audio" : "Zvočni posnetek",
    "Images" : "Slike",
    "Videos" : "Video posnetki",
    "Filters" : "Filtri",
    "Appearance" : "Videz",
    "Show hidden files" : "Pokaži skrite datoteke",
    "Crop image previews" : "Obreži slike predogleda",
    "General" : "Splošno",
    "Sort favorites first" : "Razvrsti najprej priljubljene",
    "Sort folders before files" : "Razvrsti mape pred datotekami",
    "All files" : "Vse datoteke",
    "Personal files" : "Osebne datoteke",
    "Additional settings" : "Dodatne nastavitve",
    "Actions" : "Dejanja",
    "Selection" : "Izbor",
    "Select all files" : "Izberi vse datoteke",
    "Deselect all" : "Odstrani celoten izbor",
    "Navigation" : "Krmarjenje",
    "View" : "Pogled",
    "Toggle grid view" : "Preklopi mrežni pogled",
    "Show those shortcuts" : "Pokaži tipkovne bližnjice",
    "Warnings" : "Opozorila",
    "WebDAV URL" : "Naslov URL WebDAV",
    "Total rows summary" : "Skupni povzetek vrstic",
    "Toggle selection for all files and folders" : "Preklopi izbor za vse datoteke in mape",
    "Name" : "Ime",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno",
    "(selected)" : "(izbrano)",
    "List of files and folders." : "Seznam datotek in map",
    "You have used your space quota and cannot upload files anymore." : "Porabili ste dodeljeno količino prostora, zato datotek ni mogoče več pošiljati.",
    "Column headers with buttons are sortable." : "Stolpce z gumbi je mogoče razvrščati.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
    "File not found" : "Datoteke ni mogoče najti",
    "Owner" : "Lastnik",
    "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
    "{used} of {quota} used" : "V uporabi je {used} od {quota}",
    "{relative}% used" : "Zasedeno {relative} %",
    "Could not refresh storage stats" : "Ni mogoče osvežiti podatkov shrambe",
    "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
    "Storage information" : "Podrobnosti shrambe",
    "Storage quota" : "Omejitev shrambe",
    "New folder" : "Nova mapa",
    "Create new folder" : "Ustvari novo mapo",
    "This name is already in use." : "Vpisano uporabniško ime je že v uporabi",
    "Create" : "Ustvari",
    "Refresh" : "Osveži",
    "Limit" : "Omejitve",
    "Fill template fields" : "Zapolni polja predloge",
    "Submit" : "Pošlji",
    "Choose a file or folder to transfer" : "Izbor datoteke ali mape za prenos",
    "Transfer" : "Prenos",
    "Transfer {path} to {userid}" : "Prenesi pot {path} k uporabniku {userid}",
    "Invalid path selected" : "Izbrana je neveljavna pot",
    "Unknown error" : "Neznana napaka",
    "Ownership transfer request sent" : "Zahteva za prenos lastništva je poslana",
    "Cannot transfer ownership of a file or folder you do not own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
    "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
    "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
    "Change" : "Spremeni",
    "New owner" : "Nov lastnik",
    "Keep {old}" : "Ohrani {old}",
    "Keep without extension" : "Ohrani brez pripone",
    "Use {new}" : "Uporabi {new}",
    "Remove extension" : "Odstrani pripono",
    "Change file extension" : "Spremeni pripono datoteke",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Sprememba končnice datoteke iz \"{old}\" v \"{new}\" lahko naredi datoteko neberljivo.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Odstranitev končnice datoteke \"{old}\" lahko naredi datoteko neberljivo.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Dadajanje končnice datoteke \"{new}\" lahko naredi datoteko neberljivo.",
    "Do not show this dialog again." : "Pogovornega okna ne pokaži več.",
    "Cancel" : "Prekliči",
    "Rename" : "Preimenuj",
    "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
    "Choose {file}" : "Izberite datoteko {file}",
    "Files settings" : "Nastavitve datotek",
    "Switch to list view" : "Preklopi na seznamski pogled",
    "Switch to grid view" : "Preklopi na mrežni pogled",
    "The file could not be found" : "Datoteke ni mogoče najti.",
    "Upload was cancelled by user" : "Uporabnik je pošiljanje preklical",
    "Not enough free space" : "Ni dovolj prostora",
    "Operation is blocked by access control" : "Opravilo je zaustavljeno prek nadzora dostopa",
    "Error during upload: {message}" : "Napaka med nalaganjem: {message}",
    "Error during upload, status code {status}" : "Napaka med nalaganje s kodo stanja {status}",
    "Unknown error during upload" : "Med pošiljanjem je prišlo do neznane napake",
    "Loading current folder" : "Poteka nalaganje trenutne mape",
    "Retry" : "Poskusi znova     ",
    "No files in here" : "V mapi ni datotek",
    "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
    "Go back" : "Skoči nazaj",
    "Views" : "Pogledi",
    "Your files" : "Osebne datoteke",
    "Open in files" : "Odpri datoteko v mapi",
    "File cannot be accessed" : "Do datoteke dostop ni mogoč",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Datoteke ni bilo mogoče najti ali pa nimate ustreznih dovoljenj za ogled. Prosite pošiljatelja, da jo deli.",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Dovoli omejitev imen datotek za zagotovitev sinhronizacije datotek z vsemi odjemalci. Privzeto je dovoljenje za vsa imena datotek na POSIX (tj. Linux ali macOS).",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Po vklopu imen, ki so združljiva z WIndows, obstoječih datotek ni več mogoče spreminjati, jih pa lahko lastnik preimenuje v ustrezno ime.",
    "Files compatibility" : "Skladnost datotek",
    "Enforce Windows compatibility" : "Vsili skladnost s sistemom Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "To bo blokiralo imena datotek, ki niso ustrezna za Windows sisteme, kot so rezervirana imena ali posebni znaki, ne bo pa to vsililo združljivosti pri razlikovanju velikih in malih črk imena.",
    "Blank" : "Prazno",
    "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
    "Pick a template for {name}" : "Izbor predloge za {name}",
    "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
    "Creating file" : "Poteka ustvarjanje datoteke",
    "Save as {displayName}" : "Shrani kot {displayName}",
    "Failed to convert files: {message}" : "Pretvarjanje datotek je spodletelo: {message}",
    "All files failed to be converted" : "Spodletelo je pretvarjanje vseh datotek.",
    "One file could not be converted: {message}" : "Ene datoteke ni mogoče pretvoriti: {message}",
    "Failed to convert files" : "Pretvarjanje datotek je spodletelo",
    "File successfully converted" : "Datoteka je uspešno pretvorjena",
    "Failed to convert file: {message}" : "Pretvarjanje datoteek je spodletelo: {message}",
    "Failed to convert file" : "Pretvarjanje datoteke je spodletelo",
    "Delete" : "Izbriši",
    "Leave this share" : "Prekini to souporabo",
    "Leave these shares" : "Prekini to souporabo",
    "Disconnect storage" : "Odklopi shrambo",
    "Disconnect storages" : "Odklopi shrambo",
    "Delete permanently" : "Izbriši trajno",
    "Delete and unshare" : "Izbriši in prekini souporabo",
    "Delete file" : "Izbriši datoteko",
    "Delete files" : "Izbriši datoteke",
    "Delete folder" : "Izbriši mapo",
    "Delete folders" : "Izbriši mape",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Za stalno boste izbrisali {count} predmet","Za stalno boste izbrisali {count} predmeta","Za stalno boste izbrisali {count} predmete","Za stalno boste izbrisali {count} predmetov"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Izbrisali boste {count} predmet","Izbrisali boste {count} predmeta","Izbrisali boste {count} predmete","Izbrisali boste {count} predmetov"],
    "Confirm deletion" : "Potrdi brisanje",
    "Download" : "Prejmi",
    "Add to favorites" : "Dodaj med priljubljene",
    "Remove from favorites" : "Odstrani iz priljubljenih",
    "Move" : "Premakni",
    "Copy" : "Kopiraj",
    "Move or copy" : "Premakni ali kopiraj",
    "Destination is not a folder" : "Ciljno mesto ni mapa",
    "This file/folder is already in that directory" : "Ta datoteka oziroma mapa je že v določeni mapi",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
    "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
    "The files are locked" : "Datoteke so zaklenjene",
    "The file does not exist anymore" : "Datoteka ne obstaja več",
    "Choose destination" : "Izbor ciljnega mesta",
    "Copy to {target}" : "Kopiraj na {target}",
    "Move to {target}" : "Premakni na {target}",
    "Move or copy operation failed" : "Opravilo kopiranja oziroma premikanja je spodletelo",
    "Open folder" : "Odpri mapo",
    "Open folder {displayName}" : "Odpri mapo {displayName}",
    "Open in Files" : "Open in Files",
    "Open locally" : "Odpri krajevno",
    "Failed to redirect to client" : "Preusmerjanje odjemalca je spodletelo",
    "Open file locally" : "Odpri datoteko krajevno",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Datoteka bi se sedaj morala odpreti z vaše naprave. Če se to ne zgodi, preverite namestitev namizne aplikacije.",
    "Retry and close" : "Ponovno poskusi in zapri",
    "Open online" : "Odpri v brskalniku",
    "Details" : "Podrobnosti",
    "View in folder" : "Pokaži v mapi",
    "Type" : "Vrsta",
    "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
    "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
    "Create templates folder" : "Ustvari mapo predlog",
    "Templates" : "Predloge",
    "New template folder" : "Nova mapa predlog",
    "In folder" : "V mapi",
    "Search in folder: {folder}" : "Išči v mapi: {folder}",
    "One of the dropped files could not be processed" : "Eno od podanih datotek ni bilo mogoče obdelati",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Brskalnik ne podpira API datotečnega sistema. Mape ne bodo naložene",
    "No files to upload" : "Ni datotek za pošiljanje",
    "Unable to create the directory {directory}" : "Mape {directory} ni mogoče ustvariti",
    "Some files could not be uploaded" : "Nekaterih datotek ni bilo mogoče poslati",
    "Files uploaded successfully" : "Datoteke so uspešno poslane v oblak",
    "No files to process" : "Ni datotek za obdelavo",
    "Files copied successfully" : "Datoteke so uspešno kopirane",
    "Files moved successfully" : "Datoteke so uspešno premaknjene",
    "Some files could not be copied" : "Nekaterih datotek ni bilo mogoče kopirati",
    "Some files could not be moved" : "Nekaterih datotek ni mogoče premakniti",
    "Conflicts resolution skipped" : "Razreševanje sporov je preklicano",
    "Upload cancelled" : "Pošiljanje je bilo preklicano",
    "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
    "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
    "This operation is forbidden" : "To dejanje ni dovoljeno!",
    "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
    "Unexpected error: {error}" : "Nepričakovana napaka: {error}",
    "_%n file_::_%n files_" : ["%n datoteka","%n datoteki","%n datoteke","%n datotek"],
    "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n mape"],
    "_%n hidden_::_%n hidden_" : ["%n skrita","%n skriti","%n skrite","%n skritih"],
    "Filename must not be empty." : "Ime datoteke ne sme biti prazno.",
    "\"{char}\" is not allowed inside a filename." : "Znak \"{char}\" ni dovoljen v imenu datotek.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" je rezervirano ime in ni dovoljeno za ime datoteke.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" ni dovoljena vrsta končnice.",
    "Filenames must not end with \"{extension}\"." : "Imena datotek naj nimajo končnice \"{extension}\".",
    "List of favorite files and folders." : "Seznam priljubljenih datotek in map.",
    "No favorites yet" : "Ni še dodanih priljubljenih predmetov",
    "Files and folders you mark as favorite will show up here" : "Datoteke ali mape, ki so označene kot priljubljene, bodo zbrane na tem mestu.",
    "List of your files and folders." : "Seznam datotek in map.",
    "List of your files and folders that are not shared." : "Seznam datotek in map, ki niso v skupni rabi.",
    "No personal files found" : "Ni najdenih zasebnih datotek",
    "Files that are not shared will show up here." : "Datoteke, ki niso v skupni rabi, bodo prikazane tukaj.",
    "Recent" : "Nedavne",
    "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
    "No recently modified files" : "Ni nedavno spremenjenih datotek",
    "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
    "Search" : "Poišči",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Select all" : "izberi vse",
    "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
    "Upload (max. %s)" : "Pošiljanje (omejitev %s)",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Datoteke lahko po vklopu te možnosti tudi same migrirajo. Preverite dokumentacijo o ukazu occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Preimenuj »{oldName}« to »{newName}«",
    "Clear filter" : "Počisti filter",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" ni uspel za nekatere elemente",
    "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
    "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
    "Submitting fields …" : "Pošiljanje polj ...",
    "Shared by link" : "V souporabi sk povezavo",
    "Shared" : "V souporabi",
    "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
    "Filter file names …" : "Filtriraj imena datotek...",
    "Clipboard is not available" : "Odložišče ni na voljo",
    "WebDAV URL copied to clipboard" : "Naslov URL WebDAV je kopiran v odložišče",
    "Enable the grid view" : "Omogoči mrežni pogled",
    "Enable folder tree" : "Omogoči drevesno strukturo map",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Kopiraj v odložišče",
    "Use this address to access your Files via WebDAV" : "Uporabite ta naslov za dostop do datotek z uporabo WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Če je omogočen sistem dvostopenjskega overjanja 2FA, je treba ustvariti in uporabiti novo geslo programa s klikom na to mesto.",
    "Prevent warning dialogs from open or reenable them." : "Preprečite odpiranje dialogov z opozorili ali jih ponovno omogočite.",
    "Show a warning dialog when changing a file extension." : "Prikaži opozorilo ob spreminjanju končnice datoteke.",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Speed up your Files experience with these quick shortcuts." : "Pospešite uporabo upravljalnika Files s temi bližnjicami.",
    "Open the actions menu for a file" : "Odpri meni dejanj za datoteko",
    "Rename a file" : "Preimenuj datoteko",
    "Delete a file" : "Izbriši datoteko",
    "Favorite or remove a file from favorites" : "Označi ali odstrani koz priljubljeno",
    "Manage tags for a file" : "Upravljanje oznak datoteke",
    "Deselect all files" : "Ostrani izbor vseh datotek",
    "Select or deselect a file" : "Izberi ali odstrani izbor datoteke",
    "Select a range of files" : "Izbor obsega datotek",
    "Navigate to the parent folder" : "Pojdi na nadrejeni imenik",
    "Navigate to the file above" : "Pojdi na datoteko zgoraj",
    "Navigate to the file below" : "Pojdi na doatoteko spodaj",
    "Navigate to the file on the left (in grid mode)" : "Pojdi na datoteko na levi (v mrežnem načinu)",
    "Navigate to the file on the right (in grid mode)" : "Pojdi na datoteko na desni (v mrežnem načinu)",
    "Toggle the grid view" : "Preklopi mrežni način",
    "Open the sidebar for a file" : "Odpri stransko okno za datoteko",
    "You" : "Jaz",
    "Shared multiple times with different people" : "V več souporabah z različnimi uporabniki",
    "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
    "Tags" : "Oznake",
    "Save as …" : "Shrani kot ...",
    "Converting files …" : "Poteka pretvarjanje datotek ...",
    "Converting file …" : "Poteka pretvarjanje datoteke ...",
    "Deletion cancelled" : "Brisanje je bilo preklicano",
    "Edit locally" : "Uredi krajevno",
    "Moving \"{source}\" to \"{destination}\" …" : "Premik \"{source}\" v \"{destination}\"...",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopiranje \"{source}\" v \"{destination}\"...",
    "(copy)" : "(kopija)",
    "(copy %n)" : "(kopija %n)",
    "Move cancelled" : "Premikanje je bilo preklicano",
    "Cancelled move or copy of \"{filename}\"." : "Prekinjeno premikanje ali kopiranje za \"{filename}\".",
    "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
    "Open details" : "Odpri podrobnosti",
    "Photos and images" : "Slike in fotografije",
    "New folder creation cancelled" : "Ustvarjanje nove mape je bilo preklicano",
    "This directory is unavailable, please check the logs or contact the administrator" : "Mapa ni na voljo. Preverite dnevnik in stopite v stik s skrbnikom sistema.",
    "All folders" : "Vse mape"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
